/*********************************************
Project : Commande du Vigipark (TP1)
Version : 1
Mise  jour: 28/10/2010
Author  : Philippe Mariano
Company : LYCEE Pierre Emile MARTIN
Comments: Le bras est  l'arrt et en position haute
L'appui sur UHF lance le cycle:
descente -> remontee -> arret
Cible: Carte SSI
Chip type           : ATMEGA8535
Clock frequency     : 8,000000 MHz
Memory model        : Small
Internal SRAM size  : 512
External SRAM size  : 0
Data Stack size     : 128
*********************************************/

#include <mega8535.h>

// Bibliothques non gnres par Wizard (rajoutes manuellement)
// -----------------------------------------------------------------------------------------------------
#include <ssi2.h>     // contient les fonctions Lire_BP, Affiche_LCD
#include <delay.h>    // contient la fonction delay_ms
#include <stdio.h>    // contient la fonction sprintf

// Etats du graphe des transitions
// -----------------------------------------------------------------------------------------------------
#define Arret	  0
#define Monter 	  1
#define Descendre 2

// Alphanumeric LCD Module functions
#asm
   .equ __lcd_port=0x15
#endasm
#include <lcd.h>

// =====================================================================================================
// Programme principal
// =====================================================================================================
void main(void)
{  // Dbut prog principal
// Declare your local variables here
// -----------------------------------------------------------------------------------------------------
// type 	nom              		Description
// -----------------------------------------------------------------------------------------------------
char display_buffer_ligne0[17]; 	// tampon ligne 0 de l'afficheur
char display_buffer_ligne1[17]; 	// tampon ligne 1 de l'afficheur
unsigned char Aff=0, Aff_1=0;
unsigned char BP_UHF, CAPT_HAUT, CAPT_BAS, Moteur, Etat;
// -----------------------------------------------------------------------------------------------------
// Input/Output Ports initialization
// Port A initialization
PORTA=0x3F; 		// ne pas modifier cette valeur
DDRA=0x00;

// Port B initialization
PORTB=0x00;             // ne pas modifier cette valeur
DDRB=0x1f;

// LCD module initialization
lcd_init(16);
// -----------------------------------------------------------------------------------------------------
// --------------------------------------- Message d'accueil -------------------------------------------
sprintf(display_buffer_ligne0,"  TP1 VIGIPARK  ");
sprintf(display_buffer_ligne1,"   SIMULATION   ");
Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);
delay_ms(3000);
// -----------------------------------------------------------------------------------------------------
sprintf(display_buffer_ligne0,"   PROG CYCLE   ");
// -----------------------------------------------------------------------------------------------------
// Initialisation du graphe et des sorties
Etat = Arret; Moteur = 0;
// -----------------------------------------------------------------------------------------------------
// =====================================================================================================
// Boucle principale
// =====================================================================================================
while(1)  // Rpter toujours
 {
//-------------------------------------------------------------------------------------------------------
// REMARQUES:
// L'tat logique actif des BP de la carte SSI est 0 : les bits du Port A sont donc inverss par ~
// Appuyer sur le BP DEC pour simuler la descente du bras
// Appuyer sur le BP OK pour simuler le capteur bas
// Appuyer sur le BP ECHAP pour simuler le capteur haut
//-------------------------------------------------------------------------------------------------------
// Lecture des entres
//-------------------------------------------------------------------------------------------------------
   BP_UHF = (~PINA & 0x10);
   CAPT_HAUT = (~PINA & 0x04);
   CAPT_BAS = (~PINA & 0x08);
//-------------------------------------------------------------------------------------------------------
// Traitement
//-------------------------------------------------------------------------------------------------------
   switch (Etat) // dbut selon
   {                            // Etat Arret
     case Arret: Moteur = 0;
                 if (BP_UHF == 0x10) Etat = Descendre;		// <-   complter
                                else Etat = Arret;	        // <-   complter
     break;

   					            // Etat Descendre
     case Descendre: Moteur = 2;  	                        // <-   complter
                if (CAPT_BAS == 0x08) Etat = Monter; 	    // <-   complter
      		                     else Etat = Descendre;    // <-   complter
     break;

                                // Etat Monter
     case Monter: Moteur = 4;                               // <-   complter
      		    if (CAPT_HAUT == 0x04)	Etat =	Arret;      // <-   complter
      		                       else Etat = Monter;	    // <-   complter
     break;

     default : Etat = Arret;
    } // fin selon
//-------------------------------------------------------------------------------------------------------
// Ecriture des sorties
//-------------------------------------------------------------------------------------------------------
    PORTB = Moteur;
//-------------------------------------------------------------------------------------------------------
// 	Gestion de l'affichage
//-------------------------------------------------------------------------------------------------------
        if (Etat == Monter){sprintf(display_buffer_ligne1," Montee du bras ");Aff=0;}
       	    else  if(Etat == Arret){sprintf(display_buffer_ligne1,"  Arret Moteur  ");Aff=1;}
       		    else {sprintf(display_buffer_ligne1,"Descente du bras");Aff=2;}

       if (Aff != Aff_1) {Affiche_LCD(display_buffer_ligne0,display_buffer_ligne1);Aff_1=Aff;}
 };// fin rpter toujours
 //-------------------------------------------------------------------------------------------------------
}// fin prog principal
// ======================================================================================================